@@ -2,7 +2,7 @@
    drvSWF.cpp : This file is part of pstoedit
    Skeleton for the implementation of new backends
 
-   Copyright (C) 1993 - 2014 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2018 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -39,8 +39,9 @@
 #define USE_PNG 1
 // #include "ming_config.h"
 
-#if defined(_WIN32)
+#if defined(_WIN32) && (_MSC_VER < 1900)
 extern "C" {
+
 	double rint(double arg) {
 		return ((long) arg);
 		// just as a quick workaround
